@@ -10,39 +10,41 @@ from lkml import tokens
 # `dimensions`.
 
 PLURAL_KEYS: Tuple[str, ...] = (
-    "view",
-    "measure",
+    "access_filter",
+    "access_grant",
+    "action",
+    "aggregate_table",
+    "allowed_value",
+    "assert",
+    "bind_filters",
+    "column",
+    "constant",
+    "datagroup",
+    "derived_column",
     "dimension",
     "dimension_group",
+    "explore",
+    "extends",
     "filter",
     "filters",
-    "access_filter",
-    "bind_filters",
-    "map_layer",
-    "parameter",
-    "set",
-    "column",
-    "derived_column",
-    "include",
-    "explore",
-    "link",
-    "when",
-    "allowed_value",
-    "named_value_format",
-    "join",
-    "datagroup",
-    "access_grant",
-    "sql_step",
-    "action",
-    "param",
     "form_param",
+    "include",
+    "join",
+    "link",
+    "map_layer",
+    "measure",
+    "named_value_format",
     "option",
-    "user_attribute_param",
-    "assert",
-    "test",
+    "override_constant",
+    "param",
+    "parameter",
     "query",
-    "extends",
-    "aggregate_table",
+    "set",
+    "sql_step",
+    "test",
+    "user_attribute_param",
+    "view",
+    "when",
 )
 
 # These are keys in LookML that should be recognized as expression blocks (end with ;;).
@@ -67,6 +69,7 @@ EXPR_BLOCK_KEYS: Tuple[str, ...] = (
     "sql_step",
     "sql_on",
     "sql",
+    "sql_preamble",
 )
 
 # These are keys that the serializer should quote the value of (e.g. `label: "Label"`).
@@ -106,6 +109,7 @@ QUOTED_LITERAL_KEYS: Tuple[str, ...] = (
     "property_key",
     "property_label_key",
     "else",
+    "interval_trigger",
 )
 
 # These are keys for fields in Looker that have a "name" attribute. Since lkml uses the
