@@ -144,11 +144,17 @@ class Parser:
             raise ValueError("Token %s does not have a consumable value." % token)
         return token.value
 
-    def consume_trivia(self) -> str:
+    def consume_trivia(self, only_newlines: bool = False) -> str:
         """Returns all continuous trivia values."""
+        valid_tokens: Tuple[Type[tokens.TriviaToken], ...] = (tokens.CommentToken,)
+        if only_newlines:
+            valid_tokens += (tokens.LinebreakToken,)
+        else:
+            valid_tokens += (tokens.WhitespaceToken,)
+
         trivia = ""
         while True:
-            if self.check(tokens.CommentToken, tokens.WhitespaceToken):
+            if self.check(*valid_tokens):
                 trivia += self.consume_token_value()
             else:
                 break
@@ -192,7 +198,7 @@ class Parser:
             # Reached the end of the stream
             result = False
         else:
-            if type(token) in token_types:
+            if isinstance(token, token_types):
                 result = True
             else:
                 result = False
@@ -280,8 +286,9 @@ class Parser:
             return key
 
         if self.check(tokens.LiteralToken):
+            token = self.consume()
             name: Optional[tree.SyntaxToken] = tree.SyntaxToken(
-                self.consume_token_value()
+                token.value, token.line_number
             )
         else:
             name = None
@@ -299,7 +306,7 @@ class Parser:
         prefix = self.consume_trivia()
         if self.check(tokens.BlockEndToken):
             self.advance()
-            suffix = self.consume_trivia()
+            suffix = self.consume_trivia(only_newlines=True)
             right_brace = tree.RightCurlyBrace(prefix=prefix, suffix=suffix)
 
             block = tree.BlockNode(
@@ -334,7 +341,7 @@ class Parser:
         key = self.parse_key()
         if key is None:
             return None
-        value = self.parse_value()
+        value = self.parse_value(parse_prefix=True, parse_suffix=True)
         if value is None:
             return None
 
@@ -358,16 +365,21 @@ class Parser:
             logger.debug("%sTry to parse %s", self.depth * DELIMITER, grammar)
         prefix = self.consume_trivia()
         if self.check(tokens.LiteralToken):
-            key = tree.SyntaxToken(self.consume_token_value(), prefix=prefix)
+            token = self.consume()
+            key = tree.SyntaxToken(token.value, token.line_number, prefix=prefix)
         else:
             return None
 
         prefix = self.consume_trivia()
-        if self.check(tokens.ValueToken):
-            self.advance()
+
+        colon = None
+        while self.check(tokens.ValueToken):
+            token = self.consume()
             suffix = self.consume_trivia()
-            colon = tree.Colon(prefix=prefix, suffix=suffix)
-        else:
+            colon = tree.Colon(
+                line_number=token.line_number, prefix=prefix, suffix=suffix
+            )
+        if not colon:
             return None
 
         if self.log_debug:
@@ -393,20 +405,29 @@ class Parser:
         prefix = self.consume_trivia() if parse_prefix else ""
 
         if self.check(tokens.LiteralToken):
-            value = self.consume_token_value()
+            token = self.consume()
+            # Handle special case where a hyphen can be preceded by whitspace
+            if token.value == "-" and self.consume_trivia():
+                if self.check(tokens.LiteralToken):
+                    token = self.consume()
+                    token.value = "-" + token.value
+                else:
+                    return None
             suffix = self.consume_trivia() if parse_suffix else ""
             if self.log_debug:
                 logger.debug("%sSuccessfully parsed value.", self.depth * DELIMITER)
-            return tree.SyntaxToken(value, prefix, suffix)
+            return tree.SyntaxToken(token.value, token.line_number, prefix, suffix)
         elif self.check(tokens.QuotedLiteralToken):
-            value = self.consume_token_value()
+            token = self.consume()
             suffix = self.consume_trivia() if parse_suffix else ""
             if self.log_debug:
                 logger.debug("%sSuccessfully parsed value.", self.depth * DELIMITER)
-            return tree.QuotedSyntaxToken(value, prefix, suffix)
+            return tree.QuotedSyntaxToken(
+                token.value, token.line_number, prefix, suffix
+            )
         elif self.check(tokens.ExpressionBlockToken):
-            value = self.consume_token_value()
-            expr_prefix, value, expr_suffix = utils.strip(value)
+            token = self.consume()
+            expr_prefix, value, expr_suffix = utils.strip(token.value)
             prefix += expr_prefix
 
             if self.check(tokens.ExpressionBlockEndToken):
@@ -416,7 +437,9 @@ class Parser:
             suffix = self.consume_trivia() if parse_suffix else ""
             if self.log_debug:
                 logger.debug("%sSuccessfully parsed value.", self.depth * DELIMITER)
-            return tree.ExpressionSyntaxToken(value, prefix, suffix, expr_suffix)
+            return tree.ExpressionSyntaxToken(
+                value, token.line_number, prefix, suffix, expr_suffix
+            )
         else:
             return None
 
